@@ -19,7 +19,7 @@
  *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
- *  DEALINGS IN THE SOFTWARE. 
+ *  DEALINGS IN THE SOFTWARE.
  *
  */
 
@@ -29,6 +29,8 @@
 #include "catalog_xliff.h"
 #include "catalog_json.h"
 #include "catalog_xcloc.h"
+#include "catalog_resx.h"
+#include "catalog_qt.h"
 
 #include "configuration.h"
 #include "errors.h"
@@ -556,6 +558,7 @@ int Catalog::FindItemIndexByLine(int lineno)
 bool Catalog::RemoveSameAsSourceTranslations()
 {
     bool changed = false;
+    const unsigned pluralFormsCount = GetPluralForms().nplurals();
 
     for (auto& i: m_items)
     {
@@ -564,7 +567,7 @@ bool Catalog::RemoveSameAsSourceTranslations()
             if (i->HasPlural())
             {
                 // we can only easily do this operation for languages that have singular+plural, skip everything else:
-                if (GetPluralFormsCount() != 2 || i->GetPluralString() != i->GetTranslation(1))
+                if (pluralFormsCount != 2 || i->GetPluralString() != i->GetTranslation(1))
                     continue;
             }
 
@@ -597,6 +600,10 @@ wxString MaskForType(Catalog::Type t)
         case Catalog::Type::JSON_FLUTTER:
             // TRANSLATORS: "Flutter" is proper noun, name of a developer tool
             return MaskForType("*.arb", _("Flutter Translation Files"));
+        case Catalog::Type::RESX:
+            return MaskForType("*.resx", _("RESX Resource Files"));
+        case Catalog::Type::QT_LINGUIST:
+            return MaskForType("*.ts", _("Qt Translation Files"));
     }
     return ""; // silence stupid warning
 }
@@ -605,9 +612,9 @@ wxString MaskForType(Catalog::Type t)
 
 wxString Catalog::GetAllTypesFileMask()
 {
-    return MaskForType("*.po;*.pot;*.xlf;*.xliff;*.xcloc;*.json;*.arb", _("All Translation Files"), /*showExt=*/false) +
+    return MaskForType("*.po;*.pot;*.xlf;*.xliff;*.xcloc;*.json;*.arb;*.resx;*.ts", _("All Translation Files"), /*showExt=*/false) +
         "|" +
-        GetTypesFileMask({ Type::PO, Type::POT, Type::XLIFF, Type::JSON, Type::JSON_FLUTTER, Type::XCLOC });
+        GetTypesFileMask({ Type::PO, Type::POT, Type::XLIFF, Type::JSON, Type::JSON_FLUTTER, Type::XCLOC, Type::RESX, Type::QT_LINGUIST });
 }
 
 wxString Catalog::GetTypesFileMask(std::initializer_list<Type> types)
@@ -772,14 +779,11 @@ std::shared_ptr<SourceCodeSpec> Catalog::GetSourceCodeSpec() const
 }
 
 
-unsigned Catalog::GetPluralFormsCount() const
+unsigned Catalog::GetPluralFormsCountPresentInItems() const
 {
     unsigned count = 0;
-
-    for (auto& i: m_items)
-    {
+    for (const auto& i: m_items)
         count = std::max(count, i->GetPluralFormsCount());
-    }
 
     return count;
 }
@@ -1133,7 +1137,9 @@ CatalogPtr Catalog::Create(Type type)
         case Type::XCLOC:
         case Type::JSON:
         case Type::JSON_FLUTTER:
-            wxFAIL_MSG("empty XLIFF/JSON creation not implemented");
+        case Type::RESX:
+        case Type::QT_LINGUIST:
+            wxFAIL_MSG("empty XLIFF/JSON/RESX/QT creation not implemented");
             return CatalogPtr();
     }
 
@@ -1164,6 +1170,14 @@ CatalogPtr Catalog::Create(const wxString& filename, int flags)
     {
         cat = XCLOCCatalog::Open(filename);
     }
+    else if (RESXCatalog::CanLoadFile(ext))
+    {
+        cat = RESXCatalog::Open(filename);
+    }
+    else if (QtLinguistCatalog::CanLoadFile(ext))
+    {
+        cat = QtLinguistCatalog::Open(filename);
+    }
 
     if (!cat)
         BOOST_THROW_EXCEPTION(Exception(_("The file is in a format not recognized by Poedit.")));
@@ -1186,7 +1200,9 @@ bool Catalog::CanLoadFile(const wxString& extension_)
 
     return POCatalog::CanLoadFile(extension) ||
            XLIFFCatalog::CanLoadFile(extension) ||
-           JSONCatalog::CanLoadFile(extension);
+           JSONCatalog::CanLoadFile(extension) ||
+           RESXCatalog::CanLoadFile(extension) ||
+           QtLinguistCatalog::CanLoadFile(extension);
 }
 
 
