@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2001-2024 Vaclav Slavik
+ *  Copyright (C) 2001-2025 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -55,7 +55,7 @@
 #include "edframe.h"
 #include "hidpi.h"
 #include "menus.h"
-#include "progressinfo.h"
+#include "progress_ui.h"
 #include "utility.h"
 
 
@@ -575,38 +575,31 @@ void ManagerFrame::OnUpdateProject(wxCommandEvent&)
          if (retval != wxID_YES)
             return;
 
-        ProgressWindow::RunCancellableTaskThenDo(this, ("Updating project catalogs"),
-        [=](dispatch::cancellation_token_ptr cancellationToken)
+        auto cancellation = std::make_shared<dispatch::cancellation_token>();
+        wxWindowPtr<ProgressWindow> progress(new ProgressWindow(this, _("Updating project catalogs"), cancellation));
+        progress->RunTaskThenDo([=]()
         {
             Progress progress((int)m_catalogs.GetCount());
 
             for (size_t i = 0; i < m_catalogs.GetCount(); i++)
             {
-                if (cancellationToken->is_cancelled())
+                if (cancellation->is_cancelled())
                     return;
 
                 wxString f = m_catalogs[i];
-                PoeditFrame *fr = PoeditFrame::Find(f);
-                if (fr)
-                {
-                    fr->UpdateCatalog();
-                }
-                else
-                {
-                    Progress subtask(1, progress, 1);
 
-                    auto cat = POCatalog::Create(f);
-                    UpdateResultReason reason;
-                    if (PerformUpdateFromSources(cat, reason))
-                    {
-                        Catalog::ValidationResults validation_results;
-                        Catalog::CompilationStatus mo_status;
-                        cat->Save(f, false, validation_results, mo_status);
-                    }
+                Progress subtask(1, progress, 1);
+
+                auto cat = POCatalog::Create(f);
+                if (auto merged = PerformUpdateFromSourcesSimple(cat))
+                {
+                    Catalog::ValidationResults validation_results;
+                    Catalog::CompilationStatus mo_status;
+                    merged.updated_catalog->Save(f, false, validation_results, mo_status);
                 }
              }
         },
-        [=](bool /*finished*/)
+        [=]()
         {
             UpdateListCat();
         });
