@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2010-2024 Vaclav Slavik
+ *  Copyright (C) 2010-2025 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -26,12 +26,6 @@
 #ifndef Poedit_utility_h
 #define Poedit_utility_h
 
-#ifndef HAVE_MKDTEMP
-    #ifdef __WXOSX__
-        #define HAVE_MKDTEMP
-    #endif
-#endif
-
 #include <map>
 
 #include <wx/arrstr.h>
@@ -219,8 +213,12 @@ public:
     TempDirectory();
     ~TempDirectory();
 
+    TempDirectory(const TempDirectory&) = delete;
+
     bool IsOk() const { return !m_dir.empty(); }
 
+    const wxString& DirName() const { return m_dir; }
+
     // creates new file name in that directory
     wxString CreateFileName(const wxString& suffix);
 
@@ -246,6 +244,8 @@ public:
     explicit TempOutputFileFor(const wxString& filename);
     explicit TempOutputFileFor(const wxFileName& filename) : TempOutputFileFor(filename.GetFullPath()) {}
 
+    TempOutputFileFor(const TempOutputFileFor&) = delete;
+
     ~TempOutputFileFor();
 
     /// Name of the temporary placeholder
